/*
   Mini XML lib PLUS for C++

   Test for iterators - path iterator

   Author: Giancarlo Niccolai <gian@niccolai.ws>

   $Id: testpath.cpp,v 1.1 2004/04/06 02:44:09 jonnymind Exp $
*/

#include <mxml_document.h>
#include <mxml_error.h>
#include <mxml.h>
#include <fstream>

#ifdef __WIN32__
#include <windows.h>
#else
#include <sys/time.h>
#endif

int main( int argc, char * argv[] )
{
   if ( argc < 2 ) {
      std::cout << "Please, use " << argv[0] << " <path/to/item>" << std::endl;
      return 0;
   }
   
   char *path = argv[1];
   
   std::cout << "Please insert a valid XML document" << std::endl;

   #ifdef __WIN32__
   SYSTEMTIME st_start, st_end;
   GetSystemTime( &st_start );
   #else
   struct timeval tv_start, tv_end;
   gettimeofday(&tv_start, NULL);
   #endif
   
   try {
      std::istream *in;
      if ( argc < 3 ) 
      {
         std::cin.unsetf( std::ios_base::skipws );
         in = &std::cin;
      }
      else
      {
         in = new std::ifstream( argv[2] );
      }
      
      std::cin.unsetf( std::ios_base::skipws );
      MXML::Document document( *in, MXML_STYLE_INDENT | MXML_STYLE_THREESPACES );
      MXML::Node *root = document.root();
      
      std::cout << "Searching for all elements in path " << path << std::endl;
      MXML::Node::iterator iter = root->find_path( path );
      
      while ( iter != root->end() ) {
         std::cout << iter->path() << "||" << iter->data() << std::endl;
         iter++;
      }
   }
   catch( MXML::Error &er )
   {
      std::cout << std::endl << er << std::endl;
   }

   #ifdef __WIN32__
   GetSystemTime( &st_end );
   std::cerr << std::endl << "Processed in " << (double)
      ( (st_end.wSecond - st_start.wSecond) * 1000 +
        (st_end.wMilliseconds - st_start.wMilliseconds ) ) 
      << " msecs" << std::endl;
   
   #else
   gettimeofday(&tv_end, NULL);
   std::cerr << std::endl << "Processed in " << (double)
      ( (tv_end.tv_sec - tv_start.tv_sec) * 1000 +
        (tv_end.tv_usec - tv_start.tv_usec ) /1000.0 ) << " msecs" << std::endl;
   #endif
   
   return 0;
}
